layout_path_for_components

Function layout_path_for_components 

pub fn layout_path_for_components(
    cr: &Context,
    layout: &Layout,
    components: RenderComponent,
)
Available on crate feature v1_58 only.
Adds components of a pango::Layout to the current path in the specified cairo context.

The top-left corner of the pango::Layout will be at the current point of the cairo context.

cr

a Cairo context

layout

a Pango layout

components

the components to include